@@ -186,7 +186,7 @@ def create_exist_pipeline_file(type, fileName):
 
         new_file = folder + "/" + fileName + ".py"
         current_init_file = folder + "/__init__.py"
-        new_init_export = "from " + currentPipelineFolder + '.' + currentDir + '.' + fileName + " import " + className
+        new_init_export = "from " + currentDir + '.' + fileName + " import " + className
 
         create_file(new_file, data)
         create_init_file(current_init_file, new_init_export)
@@ -277,7 +277,7 @@ def inject_to_pipeline(fileName, className, new_init_export):
             build_pipeline_indent = (index_of_build_pipeline.start() - index_of_build_pipeline_row.start()) * 2
             new_tab_line = new_tab_line.ljust(build_pipeline_indent + 1)
 
-        new_component_line = 'self.' + fileName + ' = ' + className + '(artifacts=self.artifacts)'
+        new_component_line = 'self.' + fileName + ' = ' + className + '()'
         add_component_line = 'self.add_component(self.' + fileName + ')'
 
         # finding imports and add components indexes
