@@ -1,7 +1,7 @@
 # !/usr/bin/env python
 # coding: utf-8
 
-from dsFramework.base.pipeline.predictables.predictable import ZIDS_Predictable
+from dsframework.base.pipeline.predictables.predictable import ZIDS_Predictable
 
 
 class generatedClass(ZIDS_Predictable):
