@@ -4,9 +4,9 @@ import uvicorn
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
 
-from generatedPipelineDir.pipeline import generatedProjectNamePipeline
-from generatedPipelineDir.schema.inputs import generatedProjectNameInputs
-from generatedPipelineDir.schema.outputs import generatedProjectNameOutputs
+from pipeline.pipeline import generatedProjectNamePipeline
+from pipeline.schema.inputs import generatedProjectNameInputs
+from pipeline.schema.outputs import generatedProjectNameOutputs
 
 app = FastAPI()
 
@@ -24,7 +24,7 @@ app.add_middleware(
 )
 
 @app.post('/predict')
-def predict(body: generatedProjectNameInputs) -> generatedProjectNameOutputs:
+def predict(body: generatedProjectNameInputs) -> List[generatedProjectNameOutputs]:
     '''
     predict api
     '''
@@ -33,14 +33,12 @@ def predict(body: generatedProjectNameInputs) -> generatedProjectNameOutputs:
 
     # call model here
     p = generatedProjectNamePipeline()
-    output = p.execute(data=data)
+    output: List[generatedProjectNameOutputs] = p.execute(**data)
     # call model here
-    if output == None:
-        output = {}
-    return generatedProjectNameOutputs(**output)
+    return output
 
 @app.post('/parse')
-def parse(body: generatedProjectNameInputs) -> generatedProjectNameOutputs:
+def parse(body: generatedProjectNameInputs) -> List[generatedProjectNameOutputs]:
     '''
     parse api
     '''
@@ -49,11 +47,9 @@ def parse(body: generatedProjectNameInputs) -> generatedProjectNameOutputs:
 
     # call model here
     p = generatedProjectNamePipeline()
-    output = p.execute(data=data)
+    output: List[generatedProjectNameOutputs] = p.execute(**data)
     # call model here
-    if output == None:
-        output = {}
-    return generatedProjectNameOutputs(**output)
+    return output
 
 @app.post('/test')
 def test(body: List[generatedProjectNameInputs]) -> List[generatedProjectNameOutputs]:
@@ -63,12 +59,12 @@ def test(body: List[generatedProjectNameInputs]) -> List[generatedProjectNameOut
     print('body',body)
 
     # call model here
-    test_output = []
-    output = []
-    for item in test_output:
-        output.append(generatedProjectNameOutputs(**item))
+    p = generatedProjectNamePipeline()
+    output: List[generatedProjectNameOutputs] = []
+    for item in body:
+        output.extend(p.execute(**item.dict()))
+    # output: List[generatedProjectNameOutputs] = p.execute(**body)
     # call model here
-
     return output
 
 @app.get("/livenessprobe")
