@@ -1,7 +1,7 @@
 import requests
 import json
 from http import HTTPStatus
-from generatedPipelineDir.schema.inputs import generatedProjectNameInputs
+from pipeline.schema.inputs import generatedProjectNameInputs
 
 
 def post(endPoint, data):
